RiveManagerState class
State for RiveManager widget
- Inheritance
-
- Object
- State<
RiveManager> - RiveManagerState
Constructors
Properties
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- controller → RiveWidgetController?
-
Get the Rive widget controller
no setter
- currentStateName → String
-
Get the current state name
no setter
- fontAssetReference → FontAsset?
-
Get the font asset reference
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageAssetReference → ImageAsset?
-
Get the image asset reference
no setter
-
inputs
→ Map<
String, Input> -
final
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
-
properties
→ List<
Map< String, dynamic> > -
Get the internal properties list
no setter
- renderTexture → RenderTexture?
-
The underlying GPU
RenderTexturewhen in texture mode, or null. Access the native pointer viarenderTexture?.nativeTexture.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- viewModelInstance → ViewModelInstance?
-
Get the ViewModel instance
no setter
- widget → RiveManager
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
captureSnapshot(
{required int width, required int height}) → Future< Image?> - Captures a snapshot of the current animation frame as a ui.Image.
-
captureSnapshotAsPng(
{required int width, required int height}) → Future< Uint8List?> - Convenience: captures a snapshot and returns PNG bytes directly.
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant RiveManager oldWidget) → void -
Called whenever the widget configuration changes.
override
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
getArtboards(
) → List< Map< String, dynamic> > - Public API: Get all artboards from the current file
-
getFontAsset(
) → FontAsset? - Public API: Get the FontAsset reference for this animation
-
getImageAsset(
) → ImageAsset? - Public API: Get the ImageAsset reference for this animation
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
loadExternalFile(
File file) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
selectArtboardByName(
String artboardName) → void - Public API: Select artboard by name
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
updateFontFromAsset(
String assetPath) → Future< void> - Public API: Load font from asset bundle
-
updateFontFromBytes(
Uint8List bytes) → Future< void> - Public API: Update font from raw bytes (.ttf, .otf)
-
updateFontFromUrl(
String url) → Future< void> - Public API: Load font from URL
-
updateImageFromAsset(
String assetPath) → Future< void> - Public API: Load image from asset bundle
-
updateImageFromBytes(
Uint8List bytes) → Future< void> - Public API: Decode image from bytes
-
updateImageFromRenderedImage(
RenderImage renderImage) → void - Public API: Update image from pre-decoded RenderImage
-
updateImageFromUrl(
String url) → Future< void> - Public API: Update image from URL
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited